@@ -6,13 +6,12 @@ use Carmel::Artifact;
 use CPAN::Meta::Requirements;
 use File::Copy::Recursive ();
 
-use subs 'path';
-use Class::Tiny qw( path );
+use Class::Tiny qw( packages );
 
 sub BUILD {
     my($self, $args) = @_;
     $self->path($args->{path});
-    $self->load_artifacts;
+    $self->packages({});
 }
 
 sub path {
@@ -56,7 +55,7 @@ sub load {
 
 sub add {
     my($self, $package, $artifact) = @_;
-    push @{$self->{$package}}, $artifact;
+    push @{$self->{packages}{$package}}, $artifact;
 }
 
 sub find {
@@ -70,7 +69,14 @@ sub find_all {
 }
 
 sub find_match {
-    my($self, $package, $cb) = @_;
+    my($self, $package, $cb, $distname) = @_;
+
+    if ($distname) {
+        my $dir = $self->path->child($distname);
+        if ($dir->exists) {
+            return Carmel::Artifact->new($dir);
+        }
+    }
 
     for my $artifact ($self->list($package)) {
         return $artifact if $cb->($artifact);
@@ -101,10 +107,13 @@ sub _find {
 
 sub list {
     my($self, $package) = @_;
+
+    $self->load_artifacts unless $self->{_loaded}++;
+
     map { $_->[2] }
       sort { $b->[0] <=> $a->[0] || $b->[1] <=> $a->[1] } # sort by the package version, then the main package version
         map { [ $_->version_for($package), $_->version, $_ ] }
-          @{$self->{$package}};
+          @{$self->{packages}{$package}};
 }
 
 1;
