@@ -15,6 +15,7 @@ use Carmel::App;
 use Capture::Tiny qw(capture);
 use File::pushd ();
 use Path::Tiny;
+use Test::More;
 
 $Carmel::Runner::UseSystem = 1;
 
@@ -84,6 +85,26 @@ sub run {
     $self->stderr($capture[1]);
 }
 
+sub run_ok {
+    my($self, @args) = @_;
+
+    $self->run(@args);
+
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    is $self->exit_code, 0
+      or diag $self->stderr;
+}
+
+sub run_fails {
+    my($self, @args) = @_;
+
+    $self->run(@args);
+
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+    is $self->exit_code, 1
+      or diag $self->stderr;
+}
+
 sub run_any {
     my($self, @args) = @_;
 
